Class: Viewy::Models::MaterializedViewDependency

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
lib/viewy/models/materialized_view_dependency.rb

Overview

Provides a means of accessing information about view dependencies from within a Rails app. The foreign key of the dependency information table is the name of the view that a user needs dependency information about.